@@ -1,7 +1,8 @@
 """Unit tests for zeroconf._cache."""
 
+from __future__ import annotations
+
 import logging
-import unittest
 import unittest.mock
 from heapq import heapify, heappop
 
